tox installation — tox 2.9.0rc2.dev55 documentation

# tox installation

## Installation with pip

Use the following command:

    pip install tox

It is fine to install `tox` itself into a virtualenv environment.

## Install from Checkout

Consult the GitHub page to get a checkout of the git repository:

> https://github.com/tox-dev/tox

and then install in your environment with something like:

    python setup.py install

or just activate your checkout in your environment like this:

    python setup.py develop

so that you can do changes and submit patches.